@@ -35,7 +35,15 @@ class Authenticator(singleton.Singleton):
         self.supports: None
         self.feed_callbacks = {}
         # also register this instance for the base Authenticator class in singleton
+        self.use_as_singleton_instance()
+
+    # pylint: disable=W0212
+    def use_as_singleton_instance(self):
+        """
+        Update the Authenticator Singleton to use self
+        """
         singleton.Singleton._instances[Authenticator] = self
+        singleton.Singleton._instances[self.__class__] = self
 
     @abc.abstractmethod
     async def login(self, username, password, password_token=None):
@@ -123,7 +131,7 @@ class Authenticator(singleton.Singleton):
         """
         await asyncio.wait_for(self.initialized_event.wait(), timeout)
 
-    async def update_trades(self, trades: list, reset: bool):
+    async def update_trades(self, trades: list, exchange_name: str, reset: bool):
         """
         Updates authenticated account trades
         """
@@ -133,6 +141,7 @@ class Authenticator(singleton.Singleton):
         self,
         current_value: dict,
         initial_value: dict,
+        profitability: float,
         unit: str,
         content: dict,
         history: dict,
