@@ -56,6 +56,7 @@ PROFILES_FOLDER = "profiles"
 USER_PROFILES_FOLDER = f"{USER_FOLDER}/{PROFILES_FOLDER}"
 PROFILE_CONFIG_FILE = "profile.json"
 CONFIG_PROFILE = "profile"
+CONFIG_BACKTESTING_PROFILE = "backtesting_profile"
 DEFAULT_PROFILE = "default"
 DEFAULT_PROFILE_FILE = f"{CONFIG_PROFILE}.json"
 CONFIG_NAME = "name"
@@ -66,6 +67,7 @@ CONFIG_READ_ONLY = "read_only"
 CONFIG_IMPORTED = "imported"
 CONFIG_COMPLEXITY = "complexity"
 CONFIG_RISK = "risk"
+CONFIG_TYPE = "type"
 PROFILE_CONFIG = "config"
 CONFIG_ID = "id"
 PROFILE_FILE_SCHEMA = f"{CONFIG_FOLDER}/profile_{SCHEMA}.json"
@@ -109,6 +111,7 @@ CONFIG_TRADER_ALLOW_ARTIFICIAL_ORDERS = "allow-artificial-orders"
 CONFIG_TRADER_RISK_MIN = 0.05
 CONFIG_TRADER_RISK_MAX = 1
 CONFIG_TRADER_REFERENCE_MARKET = "reference-market"
+DEFAULT_STORAGE_TRADING_MODE = "default"
 
 # Simulator
 CONFIG_SIMULATOR = "trader-simulator"
@@ -149,6 +152,7 @@ CONFIG_ACTIVATION_TOPICS = "activation method"
 CONFIG_TRIGGER_TIMEFRAMES = "Trigger_timeframes"
 CONFIG_EMIT_TRADING_SIGNALS = "emit_trading_signals"
 CONFIG_TRADING_SIGNALS_STRATEGY = "trading_strategy"
+ALLOW_DEFAULT_CONFIG = "allow_default_config"
 
 # terms of service
 CONFIG_ACCEPTED_TERMS = "accepted_terms"
