@@ -218,6 +218,7 @@ class BacktestingMetadata(enum.Enum):
     ID = "id"
     GAINS = "gains"
     PERCENT_GAINS = "% gains"
+    MARKETS_PROFITABILITY = "markets profitability"
     END_PORTFOLIO = "end portfolio"
     START_PORTFOLIO = "start portfolio"
     WIN_RATE = "% win rate"
@@ -481,6 +482,7 @@ class UserInputEditorOptionsTypes(enum.Enum):
 
 class UserInputOtherSchemaValuesTypes(enum.Enum):
     DESCRIPTION = "description"
+    DEPENDENCIES = "dependencies"
 
 
 class ProfileComplexity(enum.Enum):
@@ -493,3 +495,8 @@ class ProfileRisk(enum.Enum):
     LOW = 1
     MODERATE = 2
     HIGH = 3
+
+
+class ProfileType(enum.Enum):
+    LIVE = "live"
+    BACKTESTING = "backtesting"
