@@ -14,7 +14,7 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-
+import contextlib
 import logging
 
 import octobot_commons.timestamp_util as timestamp_util
@@ -35,6 +35,7 @@ error_notifier_callbacks = []
 LOGS_MAX_COUNT = 1000
 
 STORED_LOG_MIN_LEVEL = logging.WARNING
+ENABLE_WEB_INTERFACE_LOGS = True
 ERROR_PUBLICATION_ENABLED = True
 SHOULD_PUBLISH_LOGS_WHEN_RE_ENABLED = False
 
@@ -66,6 +67,19 @@ def get_global_logger_level() -> object:
     return logging.getLogger().getEffectiveLevel()
 
 
+@contextlib.contextmanager
+def temporary_log_level(level):
+    """
+    Sets the log level to the given level inside this context
+    """
+    previous_level = get_global_logger_level()
+    try:
+        set_global_logger_level(level)
+        yield
+    finally:
+        set_global_logger_level(previous_level)
+
+
 def get_logger_level_per_handler() -> list:
     """
     Return the global logger level
@@ -215,7 +229,7 @@ class BotLogger:
                     str(exception) if str(exception) else exception.__class__.__name__
                 )
             elif include_exception_name:
-                message = f"{message} ({exception.__class__.__name__})"
+                message = f"{message} (error: {exception.__class__.__name__})"
             self.error(message, skip_post_callback=True)
         self._post_callback_if_necessary(exception, error_message, skip_post_callback)
 
@@ -248,7 +262,11 @@ class BotLogger:
         :param message: the log message
         :param level: the log level
         """
-        if STORED_LOG_MIN_LEVEL <= level and get_global_logger_level() <= level:
+        if (
+            ENABLE_WEB_INTERFACE_LOGS
+            and STORED_LOG_MIN_LEVEL <= level
+            and get_global_logger_level() <= level
+        ):
             self._web_interface_publish_log(message, level)
             if not ERROR_PUBLICATION_ENABLED and logging.ERROR <= level:
                 global SHOULD_PUBLISH_LOGS_WHEN_RE_ENABLED
@@ -309,3 +327,11 @@ def set_error_publication_enabled(enabled) -> None:
         add_log(logging.ERROR, None, None, keep_log=False, call_notifiers=True)
     else:
         SHOULD_PUBLISH_LOGS_WHEN_RE_ENABLED = False
+
+
+def set_enable_web_interface_logs(enabled):
+    """
+    Disable or enable errors storage in web interface
+    """
+    global ENABLE_WEB_INTERFACE_LOGS
+    ENABLE_WEB_INTERFACE_LOGS = enabled
