@@ -142,6 +142,19 @@ def _get_row_pretty_portfolio_row(holdings, currency, ref_market, ref_market_val
     return f"{str_holdings} {currency}"
 
 
+def _get_max_digits(number):
+    abs_number = abs(number)
+    if abs_number < 0.0001:
+        return 8
+    if abs_number < 0.01:
+        return 6
+    if abs_number < 1:
+        return 4
+    if abs_number < 10000:
+        return 2
+    return 0
+
+
 def _get_markdown_pretty_portfolio_row(
     holdings, currency, ref_market, ref_market_value
 ):
@@ -149,11 +162,11 @@ def _get_markdown_pretty_portfolio_row(
     :return: the portfolio row adapted for a markdown format
     """
     str_currency = "{:<4}".format(currency)
-    str_holdings = "{:<12}".format(get_min_string_from_number(holdings, max_digits=6))
+    str_holdings = "{:<12}".format(get_min_string_from_number(holdings))
     str_ref_market_value = "{:<12}".format("")
     if ref_market:
         str_ref_market_value = "{:<12}".format(
-            get_min_string_from_number(ref_market_value) if ref_market_value else ""
+            get_min_string_from_number(ref_market_value)
         )
     return f"{str_currency} {str_holdings} {str_ref_market_value}"
 
@@ -180,7 +193,6 @@ def global_portfolio_pretty_print(
     value = "value"
     for asset, asset_dict in global_portfolio.items():
         if asset_dict[constants.PORTFOLIO_TOTAL] > 0:
-            # fill lines with empty spaces if necessary
             holdings_value = 0
             if currency_values and ref_market_name:
                 if ref_market_name == asset:
@@ -201,9 +213,9 @@ def global_portfolio_pretty_print(
                     value: holdings_value,
                 }
             )
-    # force "value" str for cythonization
-    results.sort(key=lambda r: r["value"], reverse=True)
+    results.sort(key=lambda r: r[value], reverse=True)
     if markdown:
+        # fill lines with empty spaces if necessary
         header = (
             f"{'{:<4}'.format('')} "
             f"{'  {:<9}'.format('Holdings')}  "
@@ -278,13 +290,14 @@ def round_with_decimal_count(number, max_digits=8) -> float:
     return float(get_min_string_from_number(number, max_digits))
 
 
-def get_min_string_from_number(number, max_digits=8) -> str:
+def get_min_string_from_number(number, max_digits=None) -> str:
     """
     Get a min string from number
     :param number: the number
     :param max_digits: the mex digits
     :return: the string from number
     """
+    max_digits = _get_max_digits(number) if max_digits is None else max_digits
     if number is None or round(number, max_digits) == 0.0:
         return "0"
     if number % 1 != 0:
