@@ -30,6 +30,14 @@ from octobot_commons.profiles.profile_sharing import (
     download_and_install_profile,
 )
 
+from octobot_commons.profiles import profile_data
+
+from octobot_commons.profiles.profile_data import (
+    ProfileData,
+    ExchangeData,
+    OptionsData,
+)
+
 
 __all__ = [
     "Profile",
@@ -38,4 +46,7 @@ __all__ = [
     "import_profile",
     "download_profile",
     "download_and_install_profile",
+    "ProfileData",
+    "ExchangeData",
+    "OptionsData",
 ]
