@@ -72,6 +72,7 @@ class Profile:
         self.imported: bool = False
         self.complexity: enums.ProfileComplexity = enums.ProfileComplexity.MEDIUM
         self.risk: enums.ProfileRisk = enums.ProfileRisk.MODERATE
+        self.profile_type: enums.ProfileType = enums.ProfileType.LIVE
 
         self.config: dict = {}
 
@@ -80,8 +81,14 @@ class Profile:
         Reads a profile from self.path
         :return: self
         """
-        parsed_profile = json_util.read_file(self.config_file())
-        profile_config = parsed_profile.get(constants.CONFIG_PROFILE, {})
+        return self.from_dict(json_util.read_file(self.config_file()))
+
+    def from_dict(self, profile_dict: dict):
+        """
+        Reads a profile from the given dict
+        :return: self
+        """
+        profile_config = profile_dict.get(constants.CONFIG_PROFILE, {})
         self.profile_id = profile_config.get(constants.CONFIG_ID, str(uuid.uuid4()))
         self.name = profile_config.get(constants.CONFIG_NAME, "")
         self.description = profile_config.get(constants.CONFIG_DESCRIPTION, "")
@@ -97,8 +104,11 @@ class Profile:
         self.risk = enums.ProfileRisk(
             profile_config.get(constants.CONFIG_RISK, enums.ProfileRisk.MODERATE.value)
         )
-        self.config = parsed_profile[constants.PROFILE_CONFIG]
-        if self.avatar:
+        self.profile_type = enums.ProfileType(
+            profile_config.get(constants.CONFIG_TYPE, enums.ProfileType.LIVE.value)
+        )
+        self.config = profile_dict[constants.PROFILE_CONFIG]
+        if self.avatar and self.path:
             avatar_path = os.path.join(self.path, self.avatar)
             if os.path.isfile(avatar_path):
                 self.avatar_path = avatar_path
@@ -235,8 +245,13 @@ class Profile:
                 constants.CONFIG_ORIGIN_URL: self.origin_url,
                 constants.CONFIG_READ_ONLY: self.read_only,
                 constants.CONFIG_IMPORTED: self.imported,
-                constants.CONFIG_COMPLEXITY: self.complexity.value,
-                constants.CONFIG_RISK: self.risk.value,
+                constants.CONFIG_COMPLEXITY: self.complexity.value
+                if self.complexity
+                else None,
+                constants.CONFIG_RISK: self.risk.value if self.risk else None,
+                constants.CONFIG_TYPE: self.profile_type.value
+                if self.profile_type
+                else None,
             },
             constants.PROFILE_CONFIG: self.config,
         }
